--------------------------------------------------------------------------------------------------------------
--
-- Module     : SIMS Database SQL Server 2005
-- Platform   : SIMS
-- Area       : DBUpgrade Database Patch
-- Copyright  : (c) Capita Education Services 2005-2009
--            : This code has been written by Capita Education Services for use within its own SIMS systems.
--            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any
--            : means or used without the express written permission of Capita Education Services.
-- Patch ID   : 22679
--
--------------------------------------------------------------------------------------------------------------

-- Check this is within the acceptible range
  IF NOT EXISTS(
	SELECT 1 
	FROM	sims.db_version_info
	WHERE	schema_version BETWEEN '3.62.575' AND '3.62.575')
  BEGIN
    DECLARE @error_msg2 VARCHAR(100)
    SET @error_msg2 = CHAR(10) + CHAR(13) + 'This patch is not applicable to this database version.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg2, 18, 1)
  END

-- This is a RunOnce patch - check its not already been applied.
ELSE IF EXISTS(SELECT 1 
	        FROM   sims.db_update_log 
	        WHERE	patch_id = 22679)
  BEGIN
    DECLARE @error_msg1 VARCHAR(100)
    SET @error_msg1 = CHAR(10) + CHAR(13) + 'This patch has already been run on the database and cannot be run again.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg1, 18, 1) 
  END

GO
-- START PATCH CODE



-- START PATCH SCRIPT 1

/*
Details		: Patch to disable enhanced security checking option in global config. 
			  This flag is used in the Cache class to determine whether database accesses should be checked for strongname keys.

Date		: 13/01/2017

*/

SET NOCOUNT ON

update sims.sims_global_config set enhanced_security_checking = 0


GO



-- END PATCH SCRIPT 1
GO


-- END PATCH CODE



-- Record that this patch has been updated
INSERT INTO sims.db_update_log
(
	patch_id,
	update_id,
	successful,
	description,
	update_type,
	date_applied
)
VALUES
(
	22679,
	1,
	'T',
	'Patch to disable enhanced security checking option in global config.This flag is used in the Cache class to determine whether database accesses should be checked for strongname keys.',
	'U',
	GetDate()
)

